==> open-cluster-management-operator-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/FailedProvisionConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FailedProvisionConfigBuilder extends FailedProvisionConfigFluentImpl<FailedProvisionConfigBuilder> implements VisitableBuilder<FailedProvisionConfig,FailedProvisionConfigBuilder>{
  public FailedProvisionConfigBuilder() {
    this(false);
  }
  public FailedProvisionConfigBuilder(Boolean validationEnabled) {
    this(new FailedProvisionConfig(), validationEnabled);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FailedProvisionConfig(), validationEnabled);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent,FailedProvisionConfig instance) {
    this(fluent, instance, false);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent,FailedProvisionConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withSkipGatherLogs(instance.getSkipGatherLogs());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfig instance) {
    this(instance,false);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withSkipGatherLogs(instance.getSkipGatherLogs());
    }
    this.validationEnabled = validationEnabled; 
  }
  FailedProvisionConfigFluent<?> fluent;
  Boolean validationEnabled;
  public FailedProvisionConfig build() {
    FailedProvisionConfig buildable = new FailedProvisionConfig(fluent.getSkipGatherLogs());
    return buildable;
  }
  
}

==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/FailedProvisionConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FailedProvisionConfigBuilder extends FailedProvisionConfigFluent<FailedProvisionConfigBuilder> implements VisitableBuilder<FailedProvisionConfig,FailedProvisionConfigBuilder>{
  public FailedProvisionConfigBuilder() {
    this(false);
  }
  public FailedProvisionConfigBuilder(Boolean validationEnabled) {
    this(new FailedProvisionConfig(), validationEnabled);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FailedProvisionConfig(), validationEnabled);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent,FailedProvisionConfig instance) {
    this(fluent, instance, false);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfigFluent<?> fluent,FailedProvisionConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new FailedProvisionConfig());

    if (instance != null) {
      fluent.withSkipGatherLogs(instance.getSkipGatherLogs());
      fluent.withSkipGatherLogs(instance.getSkipGatherLogs());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfig instance) {
    this(instance,false);
  }
  public FailedProvisionConfigBuilder(FailedProvisionConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new FailedProvisionConfig());

    if (instance != null) {
      this.withSkipGatherLogs(instance.getSkipGatherLogs());
      this.withSkipGatherLogs(instance.getSkipGatherLogs());
    }
    this.validationEnabled = validationEnabled; 
  }
  FailedProvisionConfigFluent<?> fluent;
  Boolean validationEnabled;
  public FailedProvisionConfig build() {
    FailedProvisionConfig buildable = new FailedProvisionConfig(fluent.getSkipGatherLogs());
    return buildable;
  }
  
}
